========================
ITRI DISCO volume driver
========================

Supported operations
~~~~~~~~~~~~~~~~~~~~

The DISCO driver supports the following features:

* Volume create and delete
* Volume attach and detach
* Snapshot create and delete
* Create volume from snapshot
* Get volume stats
* Copy image to volume
* Copy volume to image
* Clone volume
* Extend volume
* Manage and unmanage volume

Configuration options
~~~~~~~~~~~~~~~~~~~~~

.. include:: ../../tables/cinder-disco.inc
